@@ -37,6 +37,6 @@ codes = {'reset': esc+'0m',
 	}
 
 def _do(n=1, cmd=None):
-	print(codes[cmd]*n, end='')
+	print(codes[cmd]*n, end='', flush=True)
 for key in codes:
 	globals()[key] = functools.partial(_do, cmd=key)
